==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ColumnHiddenChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { ColumnHiddenChangedEventArgsDescription } from "./ColumnHiddenChangedEventArgsDescription";
/**
 * @hidden
 */
var ColumnHiddenChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnHiddenChangedEventArgsDescriptionMetadata, _super);
    function ColumnHiddenChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnHiddenChangedEventArgsDescriptionMetadata.b = function (a) {
        if (ColumnHiddenChangedEventArgsDescriptionMetadata.a == null) {
            ColumnHiddenChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnHiddenChangedEventArgsDescriptionMetadata.c(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ColumnHiddenChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
        ColumnDescriptionMetadata.d(a);
    };
    ColumnHiddenChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:Column");
        a.item("IsHidden", "Boolean");
    };
    ColumnHiddenChangedEventArgsDescriptionMetadata.d = function (a) {
        ColumnHiddenChangedEventArgsDescriptionMetadata.b(a);
        a.u("ColumnHiddenChangedEventArgs", function () { return new ColumnHiddenChangedEventArgsDescription(); });
        a.t("ColumnHiddenChangedEventArgs", ColumnHiddenChangedEventArgsDescriptionMetadata.a);
    };
    ColumnHiddenChangedEventArgsDescriptionMetadata.$t = markType(ColumnHiddenChangedEventArgsDescriptionMetadata, 'ColumnHiddenChangedEventArgsDescriptionMetadata');
    ColumnHiddenChangedEventArgsDescriptionMetadata.a = null;
    return ColumnHiddenChangedEventArgsDescriptionMetadata;
}(Base));
export { ColumnHiddenChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ColumnHiddenChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnHiddenChangedEventArgsDescription } from "./ColumnHiddenChangedEventArgsDescription";
/**
 * @hidden
 */
var ColumnHiddenChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ColumnHiddenChangedEventArgsDescriptionMetadata, _super);
    function ColumnHiddenChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnHiddenChangedEventArgsDescriptionMetadata.b = function (a) {
        if (ColumnHiddenChangedEventArgsDescriptionMetadata.a == null) {
            ColumnHiddenChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnHiddenChangedEventArgsDescriptionMetadata.c(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ColumnHiddenChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ColumnHiddenChangedEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    ColumnHiddenChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
        a.item("IsHidden", "Boolean");
    };
    ColumnHiddenChangedEventArgsDescriptionMetadata.d = function (a) {
        ColumnHiddenChangedEventArgsDescriptionMetadata.b(a);
        a.aa("ColumnHiddenChangedEventArgs", function () { return new ColumnHiddenChangedEventArgsDescription(); });
        a.z("ColumnHiddenChangedEventArgs", ColumnHiddenChangedEventArgsDescriptionMetadata.a);
    };
    ColumnHiddenChangedEventArgsDescriptionMetadata.$t = markType(ColumnHiddenChangedEventArgsDescriptionMetadata, 'ColumnHiddenChangedEventArgsDescriptionMetadata');
    ColumnHiddenChangedEventArgsDescriptionMetadata.a = null;
    return ColumnHiddenChangedEventArgsDescriptionMetadata;
}(Base));
export { ColumnHiddenChangedEventArgsDescriptionMetadata };
